/*
  10-5-10
  Pete Dokter
  SparkFun Electronics
  
  This is an example sketch for Arduino that shows very basically how to control an Ardumoto
  motor driver shield with a 5V Arduino controller board (3.3V may work, but it's out of spec
  for the L298 H-bridge logic, so no promises). If you're plugging the Ardumoto into an
  Arduino Duemilanove or similar, all the connections are done for you and you can just rewrite
  the examples in this code to your liking.
  
  Changed to reflect a new board revision...
*/


//int pwm_a = 10;  //PWM control for motor outputs 1 and 2 is on digital pin 10
#include "WProgram.h"
void setup();
void AudioControl();
void BluetoothControl();
void loop();
int pwm_a = 3;  //PWM control for motor outputs 1 and 2 is on digital pin 3
int pwm_b = 11;  //PWM control for motor outputs 3 and 4 is on digital pin 11
int dir_a = 12;  //direction control for motor outputs 1 and 2 is on digital pin 12
int dir_b = 13;  //direction control for motor outputs 3 and 4 is on digital pin 13

int ch_R = 2;    // audio channel R
int ch_L = 4;    // audio channel L

int mode = 5;    // \u97f3\u58f0\u5236\u5fa1\uff08L\uff09\u307e\u305f\u306fBluetooth\u5236\u5fa1\uff08H\uff09\u306e\u5207\u66ff\u7528\u30c7\u30b8\u30bf\u30eb\u5165\u529b\u756a\u53f7
int incomingByte=0;   // \u53d7\u4fe1\u30c7\u30fc\u30bf\u7528

unsigned int pR, pL;  // \u30d1\u30eb\u30b9\u5e45\u8a08\u6e2c\u7528\u5909\u6570


void setup()
{
  pinMode(pwm_a, OUTPUT);  //Set control pins to be outputs
  pinMode(pwm_b, OUTPUT);
  pinMode(dir_a, OUTPUT);
  pinMode(dir_b, OUTPUT);
  
  analogWrite(pwm_a, 100);  //set both motors to run at (100/255 = 39)% duty cycle (slow)
  analogWrite(pwm_b, 100);
  
  pinMode(ch_R, INPUT);    // \u53f3\u30c1\u30e3\u30f3\u30cd\u30eb\u5165\u529b\u8a2d\u5b9a
  pinMode(ch_L, INPUT);    // \u5de6\u30c1\u30e3\u30f3\u30cd\u30eb\u5165\u529b\u8a2d\u5b9a
  pinMode(mode, INPUT);    // \u97f3\u58f0\u5236\u5fa1\uff08L\uff09\u307e\u305f\u306fBluetooth\u5236\u5fa1\uff08H\uff09\u306e\u5207\u66ff
    
  Serial.begin(115200);      // BT\u63a5\u7d9a\u306b\u4f7f\u7528
  
  digitalWrite(dir_a, LOW);  //Set motor direction, 1 low, 2 high
  digitalWrite(dir_b, LOW);  //Set motor direction, 3 high, 4 low
  analogWrite(pwm_a, 0);  
  analogWrite(pwm_b, 0);  
}

// \u97f3\u58f0\u4fe1\u53f7\u306b\u3088\u308b\u30b3\u30f3\u30c8\u30ed\u30fc\u30eb
void AudioControl()
{
  pR=pulseIn(ch_R,HIGH,10000);
  pL=pulseIn(ch_L,HIGH,10000);
  
  if (pR !=0 ){
    if (pR<500) { digitalWrite(dir_a, LOW); } else {digitalWrite(dir_a, HIGH); }  
    analogWrite(pwm_a, 200);
  } else {analogWrite(pwm_a, 0); }
  
  if (pL !=0 ){
    if (pL<500) { digitalWrite(dir_b, LOW); } else {digitalWrite(dir_b, HIGH); }  
    analogWrite(pwm_b, 200);
  } else {analogWrite(pwm_b, 0); }
  
  delay(100);
}

// Bluetooth\u306b\u3088\u308b\u30b3\u30f3\u30c8\u30ed\u30fc\u30eb
void BluetoothControl()
{
  // \u30ad\u30fc\u5165\u529b\u306e\u78ba\u8a8d\uff0c\u30e2\u30fc\u30bf\u56de\u8ee2
  if (Serial.available()>0){
    incomingByte=Serial.read();
    switch (incomingByte){
       case 'f': case 'F': digitalWrite(dir_a, LOW); digitalWrite(dir_b, LOW); analogWrite(pwm_a, 200); analogWrite(pwm_b, 200); break;
       case 'r': case 'R': digitalWrite(dir_a, HIGH); digitalWrite(dir_b, LOW); analogWrite(pwm_a, 0); analogWrite(pwm_b, 200); break;
       case 'l': case 'L': digitalWrite(dir_a, LOW); digitalWrite(dir_b, HIGH); analogWrite(pwm_a, 200); analogWrite(pwm_b, 0); break;
       case 'b': case 'B': digitalWrite(dir_a, HIGH); digitalWrite(dir_b, HIGH); analogWrite(pwm_a, 200); analogWrite(pwm_b, 200); break;
       case 's': case 'S': analogWrite(pwm_a, 0); analogWrite(pwm_b, 0); break;
    }
    // f,r,l,b \u306e\u6642\u306f\uff12\u79d2\u5f8c\u306b\u6b62\u3081\u308b. F,R,L,B \u306e\u6642\u306f\u30ea\u30a2\u30eb\u30bf\u30a4\u30e0\u3067\u53cd\u5fdc\u3055\u305b\u308b
    if(incomingByte=='F' || incomingByte=='R' || incomingByte=='L' || incomingByte=='B'){
      delay(2000); analogWrite(pwm_a, 0); analogWrite(pwm_b, 0);
    }
  } 
}

void loop()
{
  if (digitalRead(mode)==LOW) AudioControl(); else BluetoothControl(); 
}
     

int main(void)
{
	init();

	setup();
    
	for (;;)
		loop();
        
	return 0;
}

